### =========================================================================
### An SQLite-based ann data package (AnnDbPkg) provides a set of pre-defined
### AnnObj objects that are created at load-time. This set depends only on
### the underlying db schema i.e. all the SQLite-based ann data packages that
### share the same underlying db schema will provide the same set of AnnObj
### objects.
###
### This file describes the set of AnnObj objects provided by any
### ENSEMBL_BASED_CHIP_DB-based package i.e. any SQLite-based ann data package based
### on the ENSEMBL_BASED_CHIP_DB schema.
### The createAnnObjs.ENSEMBL_BASED_CHIP_DB() function is the main entry point for
### this file: it is called by any ENSEMBL_BASED_CHIP_DB-based package at load-time.
### -------------------------------------------------------------------------


ENSEMBL_BASED_CHIP_DB_L2Rlink1 <- list(tablename="probes", Lcolname="probeset_id", Rcolname="_id")

### Mandatory fields: objName, Class and L2Rchain
ENSEMBL_BASED_CHIP_DB_AnnDbBimap_seeds <- list(
    list(
        objName="MAIN_ENSEMBL_ID",
        Class="AnnDbBimap",
        L2Rchain=list(
            list(
                tablename="probes",
                Lcolname="probeset_id",
                Rcolname="ensembl_id"
            )
        )
    ),
    list(
        objName="GENE_COUNT",
        Class="AnnDbBimap",
        L2Rchain=list(
            list(
                tablename="probes",
                Lcolname="probeset_id",
                Rcolname="gene_mapped"
            )
        )
    ),
    list(
        objName="TRANSCRIPT_COUNT",
        Class="AnnDbBimap",
        L2Rchain=list(
            list(
                tablename="probes",
                Lcolname="probeset_id",
                Rcolname="transcript_total"
            )
        )
    ),
    list(
        objName="TRANSCRIPT_MAPPED",
        Class="AnnDbBimap",
        L2Rchain=list(
            list(
                tablename="probes",
                Lcolname="probeset_id",
                Rcolname="transcript_mapped"
            )
        )
    ),
    list(
        objName="PROBE_QTY",
        Class="AnnDbBimap",
        L2Rchain=list(
            list(
                tablename="probes",
                Lcolname="probeset_id",
                Rcolname="probe_qty"
            )
        )
    ),
    list(
        objName="CHR",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="chromosomes",
                Lcolname="_id",
                Rcolname="chromosome"
            )
        )
    ),
    list(
        objName="CHRLOC",
        Class="AnnDbMap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="chromosome_locations",
                Lcolname="_id",
                tagname=c(Chromosome="{seqname}"),
                Rcolname="start_location"
            )
        ),
        rightColType="integer"
    ),
    list(
        objName="GENE_START",
        Class="AnnDbMap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="chromosome_locations",
                Lcolname="_id",
                tagname=c(Chromosome="{seqname}"),
                Rcolname="gene_start"
            )
        ),
        rightColType="integer"
    ),
    list(
        objName="GENE_END",
        Class="AnnDbMap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="chromosome_locations",
                Lcolname="_id",
                tagname=c(Chromosome="{seqname}"),
                Rcolname="gene_end"
            )
        ),
        rightColType="integer"
    ),
    list(
        objName="GENE_STRAND",
        Class="AnnDbMap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="chromosome_locations",
                Lcolname="_id",
                tagname=c(Chromosome="{seqname}"),
                Rcolname="gene_strand"
            )
        ),
        rightColType="integer"
    ),
    list(
        objName="BIOTYPE",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="gene_info",
                Lcolname="_id",
                Rcolname="biotype"
            )
        )
    ),
    list(
        objName="ENSEMBL",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="ensembl",
                Lcolname="_id",
                Rcolname="ensembl_id"
            )
        )
    ),
    list(
        objName="ENSEMBL_TRANSCRIPT",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="ensembl_transcript",
                Lcolname="_id",
                Rcolname="ensembl_transcript_id"
            )
        )
    ),
    list(
        objName="EMBL",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="embl",
                Lcolname="_id",
                Rcolname="embl_id"
            )
        )
    ),
    list(
        objName="ENTREZID",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="genes",
                Lcolname="_id",
                Rcolname="gene_id"
            )
        )
    ),
    list(
        objName="GENENAME",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="gene_info",
                Lcolname="_id",
                Rcolname="gene_name"
            )
        )
    ),
    list(
        objName="MAP",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="cytogenetic_locations",
                Lcolname="_id",
                Rcolname="cytogenetic_location"
            )
        )
    ),
    list(
        objName="REFSEQ",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="refseq",
                Lcolname="_id",
                Rcolname="accession"
            )
        )
    ),
    list(
        objName="SYMBOL",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="gene_info",
                Lcolname="_id",
                Rcolname="symbol"
            )
        )
    ),
    list(
        objName="UNIGENE",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="unigene",
                Lcolname="_id",
                Rcolname="unigene_id"
            )
        )
    ),
    list(
        objName="UNIPROT",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                tablename="uniprot",
                Lcolname="_id",
                Rcolname="uniprot_id"
            )
        )
    ),
    list(
        objName="GO",
        Class="AnnDbBimap",
        L2Rchain=list(
            ENSEMBL_BASED_CHIP_DB_L2Rlink1,
            list(
                 tablename="go",
                 Lcolname="_id",
                 Rcolname="go_id"
            )
        )
    )
)

createAnnObjs.ENSEMBL_BASED_CHIP_DB <- function(prefix, objTarget, dbconn, datacache){
  checkDBSCHEMA(dbconn, "ENSEMBL_BASED_CHIP_DB", "2.2")
  
  ## AnnDbBimap objects
  seed0 <- list(
		objTarget=objTarget,
		datacache=datacache
                )
  ann_objs <- AnnotationDbi:::createAnnDbBimaps(ENSEMBL_BASED_CHIP_DB_AnnDbBimap_seeds, seed0)
  
  ## Reverse maps
  ann_objs$EMBL2PROBE <- revmap(ann_objs$EMBL, objName="EMBL2PROBE")
  ann_objs$ENSEMBL2PROBE <- revmap(ann_objs$ENSEMBL, objName="ENSEMBL2PROBE")
  ann_objs$ENSEMBL_TRANSCRIPT2PROBE <- revmap(ann_objs$ENSEMBL_TRANSCRIPT, objName="ENSEMBL_TRANSCRIPT2PROBE")
  ann_objs$ENTREZID2PROBE <- revmap(ann_objs$ENTREZID, objName="ENTREZID2PROBE")
  ann_objs$GENENAME2PROBE <- revmap(ann_objs$GENENAME, objName="GENENAME2PROBE")
  ann_objs$BIOTYPE2PROBE <- revmap(ann_objs$BIOTYPE, objName="BIOTYPE2PROBE")
  ann_objs$GO2PROBE <- revmap(ann_objs$GO, objName="GO2PROBE")
  ann_objs$REFSEQ2PROBE <- revmap(ann_objs$REFSEQ, objName="REFSEQ2PROBE")
  ann_objs$SYMBOL2PROBE <- revmap(ann_objs$SYMBOL, objName="SYMBOL2PROBE")
  ann_objs$UNIGENE2PROBE <- revmap(ann_objs$UNIGENE, objName="UNIGENE2PROBE")
  ann_objs$UNIPROT2PROBE <- revmap(ann_objs$UNIPROT, objName="UNIPROT2PROBE")
  
  ## 2 special maps that are not AnnDbBimap objects (just named integer vectors)
  ann_objs$CHRLENGTHS <- AnnotationDbi:::createCHRLENGTHS(dbconn)
  ann_objs$MAPCOUNTS <- AnnotationDbi:::createMAPCOUNTS(dbconn, prefix)
  
  AnnotationDbi:::prefixAnnObjNames(ann_objs, prefix)
}

## we overload the AnnotationDbi function that enforces 2.1 as version
"checkDBSCHEMA" <- function (dbconn, DBSCHEMA, DBSCHEMAVERSION){
  schema <- dbmeta(dbconn, "DBSCHEMA")
  if (schema != DBSCHEMA) 
    stop("invalid DB schema (found ", schema, ", expected ", 
         DBSCHEMA, ")")
  version <- dbmeta(dbconn, "DBSCHEMAVERSION")
  if (version != DBSCHEMAVERSION) 
    stop("invalid DB schema version (found ", version, ", expected ", 
         DBSCHEMAVERSION, ")")
}

