\name{ensembl.based.hgu133plus2GO}
\alias{ensembl.based.hgu133plus2GO2PROBE}
\title{Map between custom probe-set IDs and Gene Ontology (GO)}
\description{
  ensembl.based.hgu133plus2GO is an R object that provides mappings between
  custom probe-set identifiers and the GO identifiers that they are
  directly associated with. 
}
\details{

  Mappings between probe identifiers and GO information were obtained through
  their mappings to EnSEMBL Gene identifiers. NAs are assigned to probe identifiers
  that can not be mapped to any Gene Ontology information. Mappings
  between Gene Ontology identifiers an Gene Ontology terms and other information
  are available in a separate data package named GO.
  
  Mappings were based on data provided by: ftp://ftp.ensembl.org/pub/release-68

  For the reverse function ensembl.based.hgu133plus2GO2PROBE, each GO term maps to a named
  vector of custom probe-set identifiers.

}

\examples{
	x <- ensembl.based.hgu133plus2GO
	# Get the probe identifiers that are mapped to a GO ID
	mapped_probes <- mappedkeys(x)
	# Convert to a list
	xx <- as.list(x[mapped_probes])
	if(length(xx) > 0) {
		# Get the GO IDs for the first five probe-sets
		xx[1:5]
		# Get the first one
		xx[6008]
	}
	# Convert to a list
	xx <- as.list(ensembl.based.hgu133plus2GO2PROBE)
	if(length(xx) > 0){
		# Get the probe identifiers for the top 2nd and 3nd GO identifiers
		xx[2:3]
		# Get the probe identifiers for the 6008th element of goids
		xx[6008]
	}
}
\keyword{datasets}
